import React from 'react'
import {
  SymbolDoubleChevronLeft,
  SymbolChevronLeft,
  SymbolChevronRight,
  SymbolDoubleChevronRight,
} from './svgs'

function paginationList(page, count) {
  let curPage = page
  const pages = []
  pages.push(curPage)
  for (let i = 0; i < count; i += 1) {
    curPage = curPage.metadata.prevpage
    if (curPage === undefined) break
    pages.unshift(curPage)
  }

  curPage = page
  for (let i = 0; i < count; i += 1) {
    curPage = curPage.metadata.nextpage
    if (curPage === undefined) break
    pages.push(curPage)
  }
  return pages
}

export function Paginator({ metadata, file, config }) {
  return (
    <ul class="pagination">
      <li>
        <a
          href={
            metadata.firstpage
              ? `${config.baseurl}/${metadata.firstpage.file}`
              : undefined
          }
        >
          <SymbolDoubleChevronLeft
            color={metadata.firstpage.file === file ? '#999' : '#000'}
            size="1em"
          />
        </a>
      </li>
      <li>
        <a
          href={
            metadata.prevpage
              ? `${config.baseurl}/${metadata.prevpage.file}`
              : undefined
          }
        >
          <SymbolChevronLeft
            color={metadata.prevpage ? '#000' : '#999'}
            size="1em"
          />
        </a>
      </li>
      {paginationList(metadata.thispage, 4).map(page =>
        page === metadata.thispage ? (
          <li class="active" key={page.pagenumber}>
            <a>{page.metadata.pagenumber}</a>
          </li>
        ) : (
          <li class="waves-effect" key={page.pagenumber}>
            <a href={`${config.baseurl}/${page.file}`}>
              {page.metadata.pagenumber}
            </a>
          </li>
        ),
      )}
      <li>
        <a
          href={
            metadata.nextpage
              ? `${config.baseurl}/${metadata.nextpage.file}`
              : undefined
          }
        >
          <SymbolChevronRight
            color={metadata.nextpage ? '#000' : '#999'}
            size="1em"
          />
        </a>
      </li>
      <li>
        <a
          href={
            metadata.lastpage
              ? `${config.baseurl}/${metadata.lastpage.file}`
              : undefined
          }
        >
          <SymbolDoubleChevronRight
            color={metadata.lastpage.file === file ? '#999' : '#000'}
            size="1em"
          />
        </a>
      </li>
    </ul>
  )
}
